#[non_exhaustive]pub enum Request<'a> {
Destroy,
GetTearingControl {
surface: WlSurface,
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Destroy
destroy tearing control factory object
Destroy this tearing control factory object. Other objects, including wp_tearing_control_v1 objects created by this factory, are not affected by this request.
This is a destructor, once sent this object cannot be used any longer.
GetTearingControl
extend surface interface for tearing control
Instantiate an interface extension for the given wl_surface to request asynchronous page flips for presentation.
If the given wl_surface already has a wp_tearing_control_v1 object associated, the tearing_control_exists protocol error is raised.
Implementations